==> support-api-1.2.2.328-yybpc-20250703.094711-1-sources.jar: com/elitesland/support/provider/org/dto/OrgStoreBaseRpcDTO.java <==
package com.elitesland.support.provider.org.dto;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

@Data
@ApiModel("门店基础信息")
public class OrgStoreBaseRpcDTO implements Serializable {
    private static final long serialVersionUID = -8218248833151483511L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主健")
    private Long id;

    @ApiModelProperty(value = "门店ID")
    private String storeCode;

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long ouId;

    @ApiModelProperty(value = "所属公司名称")
    private String ouName;

    @ApiModelProperty(value = "所属公司编码")
    private String ouCode;

    @ApiModelProperty(value = "所属组织ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long buId;

    @ApiModelProperty(value = "所属组织名称")
    private String buName;

    @ApiModelProperty(value = "所属组织编码")
    private String buCode;

    @ApiModelProperty(value = "门店类型")
    private String storeType;
    @ApiModelProperty(value = "门店类型")
    private String storeType2;

    @ApiModelProperty(value = "门店状态")
    private String storeStatus;

    @ApiModelProperty("地址号")
    private Long addrNo;

    @ApiModelProperty(value = "联系电话")
    private String storeContPhone;

    @ApiModelProperty(value = "门店负责人")
    private String storeManager;

    @ApiModelProperty("客户编码")
    private String custCode;

    @ApiModelProperty("客户名称")
    private String custName;

    @ApiModelProperty(value = "渠道类型（线上，线下）")
    private String channelType;

    @ApiModelProperty(value = "渠道编码")
    private String channelCode;

    @ApiModelProperty(value = "门店等级")
    private String storeLevel;


    @ApiModelProperty(value = "品牌id")
    private String brandId;

    @ApiModelProperty(value = "品牌编码")
    private String brandCode;

    @ApiModelProperty(value = "  品牌名称")
    private String brandName;

    @ApiModelProperty("运费是否计费")
    private Boolean freightFlag;

    @ApiModelProperty("运费比例")
    private BigDecimal freightRatio;

    @ApiModelProperty("供应商运费是否计费")
    private Boolean freightFlag2;

    @ApiModelProperty("供应商运费比例")
    private BigDecimal freightRatio2;

    @ApiModelProperty(value = "区域 []yst-supp:REGION")
//    @SysCode(sys = "yst-supp", mod = "REGION")
    private String region;
    private String regionName;

    @ApiModelProperty("仓库编码")
    private String whCode;

    @ApiModelProperty("是否日结")
    private Boolean dailyFlag;

    @ApiModelProperty("是否允许预日结")
    private Boolean preDailyFlag;

    @ApiModelProperty("是否自动日结")
    private Boolean autoDailyFlag;

    @ApiModelProperty(value = "GMV等级")
    private String gmvLevel;

    @ApiModelProperty(value = "储值公司ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long storedOuId;

    @ApiModelProperty(value = "储值公司编号")
    private String storedOuCode;

    @ApiModelProperty(value = "储值公司名称")
    private String storedOuName;

    @ApiModelProperty("仓库是否收取项目费用")
    private Boolean whChargeFlag;

    @ApiModelProperty("直送是否收取项目费用")
    private Boolean deliveryChargeFlag;

    @ApiModelProperty("省")
    private String province;

    @ApiModelProperty("市")
    private String city;

    @ApiModelProperty("县")
    private String county;

    @ApiModelProperty("国家")
    private String country;

}

==> support-api-1.2.5-yybpc-20250910.145443-1-sources.jar: com/elitesland/support/provider/org/dto/OrgStoreBaseRpcDTO.java <==
package com.elitesland.support.provider.org.dto;

import com.elitescloud.cloudt.common.annotation.Comment;
import com.elitescloud.cloudt.common.annotation.SysCode;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.persistence.Column;
import java.io.Serializable;
import java.math.BigDecimal;

@Data
@ApiModel("门店基础信息")
public class OrgStoreBaseRpcDTO implements Serializable {
    private static final long serialVersionUID = -8218248833151483511L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主健")
    private Long id;

    @ApiModelProperty(value = "门店ID")
    private String storeCode;

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long ouId;

    @ApiModelProperty(value = "所属公司名称")
    private String ouName;

    @ApiModelProperty(value = "所属公司编码")
    private String ouCode;

    @ApiModelProperty(value = "所属组织ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long buId;

    @ApiModelProperty(value = "所属组织名称")
    private String buName;

    @ApiModelProperty(value = "所属组织编码")
    private String buCode;

    @ApiModelProperty(value = "门店类型")
    private String storeType;
    @ApiModelProperty(value = "门店类型")
    private String storeType2;

    @ApiModelProperty(value = "门店状态")
    private String storeStatus;

    @ApiModelProperty("地址号")
    private Long addrNo;

    @ApiModelProperty(value = "联系电话")
    private String storeContPhone;

    @ApiModelProperty(value = "门店负责人")
    private String storeManager;

    @ApiModelProperty("客户编码")
    private String custCode;

    @ApiModelProperty("客户名称")
    private String custName;

    @ApiModelProperty(value = "渠道类型（线上，线下）")
    private String channelType;

    @ApiModelProperty(value = "渠道编码")
    private String channelCode;

    @ApiModelProperty(value = "门店等级")
    private String storeLevel;


    @ApiModelProperty(value = "品牌id")
    private String brandId;

    @ApiModelProperty(value = "品牌编码")
    private String brandCode;

    @ApiModelProperty(value = "  品牌名称")
    private String brandName;

    @ApiModelProperty("运费是否计费")
    private Boolean freightFlag;

    @ApiModelProperty("运费比例")
    private BigDecimal freightRatio;

    @ApiModelProperty("供应商运费是否计费")
    private Boolean freightFlag2;

    @ApiModelProperty("供应商运费比例")
    private BigDecimal freightRatio2;

    @ApiModelProperty(value = "区域 []yst-supp:REGION")
//    @SysCode(sys = "yst-supp", mod = "REGION")
    private String region;
    private String regionName;

    @ApiModelProperty("仓库编码")
    private String whCode;

    @ApiModelProperty("是否日结")
    private Boolean dailyFlag;

    @ApiModelProperty("是否允许预日结")
    private Boolean preDailyFlag;

    @ApiModelProperty("是否自动日结")
    private Boolean autoDailyFlag;

    @ApiModelProperty(value = "GMV等级")
    private String gmvLevel;

    @ApiModelProperty(value = "储值公司ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long storedOuId;

    @ApiModelProperty(value = "储值公司编号")
    private String storedOuCode;

    @ApiModelProperty(value = "储值公司名称")
    private String storedOuName;

    @ApiModelProperty("仓库是否收取项目费用")
    private Boolean whChargeFlag;

    @ApiModelProperty("直送是否收取项目费用")
    private Boolean deliveryChargeFlag;

    @ApiModelProperty("省")
    private String province;

    @ApiModelProperty("市")
    private String city;

    @ApiModelProperty("县")
    private String county;

    @ApiModelProperty("国家")
    private String country;

    @ApiModelProperty(value = "发票类型 [UDC]CRM:INV_TYPE")
    @SysCode(sys = "yst-sale", mod = "INV_TYPE")
    private String invType;
    private String invTypeName;

    @ApiModelProperty(value = "开票抬头")
    private String invTitle;

    @ApiModelProperty(value = "税号")
    private String taxerNo;

    @ApiModelProperty(value = "开票地址")
    private String invAddress;

    @ApiModelProperty(value = "开票电话")
    private String invTel;

    @ApiModelProperty(value = "开票开户银行")
    private String invBankName;

    @ApiModelProperty(value = "开票银行账户")
    private String invBankAcc;

    @ApiModelProperty(value = "开票联系人")
    private String invPicName;

    @ApiModelProperty(value = "开票联系人电话")
    private String invPicPhone;

    @ApiModelProperty(value = "开票邮箱")
    private String invEmail;

    @ApiModelProperty(value = "施工方门店id")
    private Long buildStoreId;

    @ApiModelProperty(value = "施工方门店编码")
    private String buildStoreCode;

    @ApiModelProperty(value = "施工方门店名称")
    private String buildStoreName;

    @ApiModelProperty(value = "监理员工id")
    private Long supervisorEmpId;

    @ApiModelProperty(value = "监理员工编码")
    private String supervisorEmpCode;

    @ApiModelProperty(value = "监理员工名称")
    private String supervisorEmpName;

    @ApiModelProperty(value = "开票抬头类型")
    private String invTitleType;

    @ApiModelProperty(value = "预计到货周期")
    private Integer expectArrivePriod;
}
